grab.spider.service.network — Grab 0.6.41 documentation

# `grab.spider.service.network`

## Module Contents

### Classes

`BaseNetworkService` |
`NetworkServiceThreaded` |

### Attributes

`NetworkResult` |

grab.spider.service.network.NetworkResult

class grab.spider.service.network.BaseNetworkService

  Bases: `grab.spider.service.base.BaseService`

  abstract get_active_threads_number() → int

class grab.spider.service.network.NetworkServiceThreaded(fatal_error_queue: queue.Queue[grab.spider.interface.FatalErrorQueueItem], thread_number: int, process_task: collections.abc.Callable[[grab.spider.task.Task], None], get_task_from_queue: collections.abc.Callable[[], None | Literal[True] | Task])

  Bases: `BaseNetworkService`

  get_active_threads_number() → int
  worker_callback(worker: grab.spider.service.base.ServiceWorker) → None